controller

package
v0.52.17 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 20, 2026 License: Apache-2.0 Imports: 16 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type PlatformMeshReconciler

type PlatformMeshReconciler struct {
	// contains filtered or unexported fields
}

PlatformMeshReconciler reconciles a PlatformMesh object

func NewPlatformMeshReconciler

func NewPlatformMeshReconciler(log *logger.Logger, mgr ctrl.Manager, cfg *config.OperatorConfig, commonCfg *pmconfig.CommonServiceConfig, dir string) *PlatformMeshReconciler

func (*PlatformMeshReconciler) Reconcile

func (r *PlatformMeshReconciler) Reconcile(ctx context.Context, req ctrl.Request) (ctrl.Result, error)

Reconcile is part of the main kubernetes reconciliation loop which aims to move the current state of the cluster closer to the desired state. TODO(user): Modify the Reconcile function to compare the state specified by the PlatformMesh object against the actual cluster state, and then perform operations to make the cluster state reflect the state specified by the user.

For more details, check Reconcile and its Result here: - https://pkg.go.dev/sigs.k8s.io/controller-runtime@v0.19.0/pkg/reconcile

func (*PlatformMeshReconciler) SetupWithManager

func (r *PlatformMeshReconciler) SetupWithManager(mgr ctrl.Manager, cfg *pmconfig.CommonServiceConfig,
	log *logger.Logger, eventPredicates ...predicate.Predicate) error

SetupWithManager sets up the controller with the Manager.

type ResourceReconciler added in v0.20.1

type ResourceReconciler struct {
	// contains filtered or unexported fields
}

ResourceReconciler reconciles a PlatformMesh object

func NewResourceReconciler added in v0.20.1

func NewResourceReconciler(log *logger.Logger, mgr ctrl.Manager, cfg *config.OperatorConfig) *ResourceReconciler

func (*ResourceReconciler) Reconcile added in v0.20.1

func (r *ResourceReconciler) Reconcile(ctx context.Context, req ctrl.Request) (ctrl.Result, error)

func (*ResourceReconciler) SetupWithManager added in v0.20.1

func (r *ResourceReconciler) SetupWithManager(mgr ctrl.Manager, cfg *pmconfig.CommonServiceConfig,
	log *logger.Logger, eventPredicates ...predicate.Predicate) error

SetupWithManager sets up the controller with the Manager.

Jump to